timespantools.Timespan
======================

.. abjad-lineage:: abjad.tools.timespantools.Timespan.Timespan

.. autoclass:: abjad.tools.timespantools.Timespan.Timespan

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.timespantools.Timespan.Timespan.axis
      ~abjad.tools.timespantools.Timespan.Timespan.contains_timespan_improperly
      ~abjad.tools.timespantools.Timespan.Timespan.curtails_timespan
      ~abjad.tools.timespantools.Timespan.Timespan.delays_timespan
      ~abjad.tools.timespantools.Timespan.Timespan.divide_by_ratio
      ~abjad.tools.timespantools.Timespan.Timespan.duration
      ~abjad.tools.timespantools.Timespan.Timespan.get_overlap_with_timespan
      ~abjad.tools.timespantools.Timespan.Timespan.happens_during_timespan
      ~abjad.tools.timespantools.Timespan.Timespan.intersects_timespan
      ~abjad.tools.timespantools.Timespan.Timespan.is_closed
      ~abjad.tools.timespantools.Timespan.Timespan.is_congruent_to_timespan
      ~abjad.tools.timespantools.Timespan.Timespan.is_half_closed
      ~abjad.tools.timespantools.Timespan.Timespan.is_half_open
      ~abjad.tools.timespantools.Timespan.Timespan.is_left_closed
      ~abjad.tools.timespantools.Timespan.Timespan.is_left_open
      ~abjad.tools.timespantools.Timespan.Timespan.is_open
      ~abjad.tools.timespantools.Timespan.Timespan.is_right_closed
      ~abjad.tools.timespantools.Timespan.Timespan.is_right_open
      ~abjad.tools.timespantools.Timespan.Timespan.is_tangent_to_timespan
      ~abjad.tools.timespantools.Timespan.Timespan.is_well_formed
      ~abjad.tools.timespantools.Timespan.Timespan.offsets
      ~abjad.tools.timespantools.Timespan.Timespan.overlaps_all_of_timespan
      ~abjad.tools.timespantools.Timespan.Timespan.overlaps_only_start_of_timespan
      ~abjad.tools.timespantools.Timespan.Timespan.overlaps_only_stop_of_timespan
      ~abjad.tools.timespantools.Timespan.Timespan.overlaps_start_of_timespan
      ~abjad.tools.timespantools.Timespan.Timespan.overlaps_stop_of_timespan
      ~abjad.tools.timespantools.Timespan.Timespan.reflect
      ~abjad.tools.timespantools.Timespan.Timespan.round_offsets
      ~abjad.tools.timespantools.Timespan.Timespan.scale
      ~abjad.tools.timespantools.Timespan.Timespan.set_duration
      ~abjad.tools.timespantools.Timespan.Timespan.set_offsets
      ~abjad.tools.timespantools.Timespan.Timespan.split_at_offset
      ~abjad.tools.timespantools.Timespan.Timespan.start_offset
      ~abjad.tools.timespantools.Timespan.Timespan.starts_after_offset
      ~abjad.tools.timespantools.Timespan.Timespan.starts_after_timespan_starts
      ~abjad.tools.timespantools.Timespan.Timespan.starts_after_timespan_stops
      ~abjad.tools.timespantools.Timespan.Timespan.starts_at_offset
      ~abjad.tools.timespantools.Timespan.Timespan.starts_at_or_after_offset
      ~abjad.tools.timespantools.Timespan.Timespan.starts_before_offset
      ~abjad.tools.timespantools.Timespan.Timespan.starts_before_or_at_offset
      ~abjad.tools.timespantools.Timespan.Timespan.starts_before_timespan_starts
      ~abjad.tools.timespantools.Timespan.Timespan.starts_before_timespan_stops
      ~abjad.tools.timespantools.Timespan.Timespan.starts_during_timespan
      ~abjad.tools.timespantools.Timespan.Timespan.starts_when_timespan_starts
      ~abjad.tools.timespantools.Timespan.Timespan.starts_when_timespan_stops
      ~abjad.tools.timespantools.Timespan.Timespan.stop_offset
      ~abjad.tools.timespantools.Timespan.Timespan.stops_after_offset
      ~abjad.tools.timespantools.Timespan.Timespan.stops_after_timespan_starts
      ~abjad.tools.timespantools.Timespan.Timespan.stops_after_timespan_stops
      ~abjad.tools.timespantools.Timespan.Timespan.stops_at_offset
      ~abjad.tools.timespantools.Timespan.Timespan.stops_at_or_after_offset
      ~abjad.tools.timespantools.Timespan.Timespan.stops_before_offset
      ~abjad.tools.timespantools.Timespan.Timespan.stops_before_or_at_offset
      ~abjad.tools.timespantools.Timespan.Timespan.stops_before_timespan_starts
      ~abjad.tools.timespantools.Timespan.Timespan.stops_before_timespan_stops
      ~abjad.tools.timespantools.Timespan.Timespan.stops_during_timespan
      ~abjad.tools.timespantools.Timespan.Timespan.stops_when_timespan_starts
      ~abjad.tools.timespantools.Timespan.Timespan.stops_when_timespan_stops
      ~abjad.tools.timespantools.Timespan.Timespan.stretch
      ~abjad.tools.timespantools.Timespan.Timespan.translate
      ~abjad.tools.timespantools.Timespan.Timespan.translate_offsets
      ~abjad.tools.timespantools.Timespan.Timespan.trisects_timespan
      ~abjad.tools.timespantools.Timespan.Timespan.__and__
      ~abjad.tools.timespantools.Timespan.Timespan.__eq__
      ~abjad.tools.timespantools.Timespan.Timespan.__format__
      ~abjad.tools.timespantools.Timespan.Timespan.__ge__
      ~abjad.tools.timespantools.Timespan.Timespan.__gt__
      ~abjad.tools.timespantools.Timespan.Timespan.__le__
      ~abjad.tools.timespantools.Timespan.Timespan.__len__
      ~abjad.tools.timespantools.Timespan.Timespan.__lt__
      ~abjad.tools.timespantools.Timespan.Timespan.__makenew__
      ~abjad.tools.timespantools.Timespan.Timespan.__ne__
      ~abjad.tools.timespantools.Timespan.Timespan.__or__
      ~abjad.tools.timespantools.Timespan.Timespan.__repr__
      ~abjad.tools.timespantools.Timespan.Timespan.__sub__
      ~abjad.tools.timespantools.Timespan.Timespan.__xor__

Bases
-----

- :py:class:`mathtools.BoundedObject <abjad.tools.mathtools.BoundedObject.BoundedObject>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.timespantools.Timespan.Timespan.axis
   :noindex:

.. autoattribute:: abjad.tools.timespantools.Timespan.Timespan.duration
   :noindex:

.. autoattribute:: abjad.tools.timespantools.Timespan.Timespan.is_closed
   :noindex:

.. autoattribute:: abjad.tools.timespantools.Timespan.Timespan.is_half_closed
   :noindex:

.. autoattribute:: abjad.tools.timespantools.Timespan.Timespan.is_half_open
   :noindex:

.. autoattribute:: abjad.tools.timespantools.Timespan.Timespan.is_left_closed
   :noindex:

.. autoattribute:: abjad.tools.timespantools.Timespan.Timespan.is_left_open
   :noindex:

.. autoattribute:: abjad.tools.timespantools.Timespan.Timespan.is_open
   :noindex:

.. autoattribute:: abjad.tools.timespantools.Timespan.Timespan.is_right_closed
   :noindex:

.. autoattribute:: abjad.tools.timespantools.Timespan.Timespan.is_right_open
   :noindex:

.. autoattribute:: abjad.tools.timespantools.Timespan.Timespan.is_well_formed
   :noindex:

.. autoattribute:: abjad.tools.timespantools.Timespan.Timespan.offsets
   :noindex:

.. autoattribute:: abjad.tools.timespantools.Timespan.Timespan.start_offset
   :noindex:

.. autoattribute:: abjad.tools.timespantools.Timespan.Timespan.stop_offset
   :noindex:

Methods
-------

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.contains_timespan_improperly
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.curtails_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.delays_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.divide_by_ratio
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.get_overlap_with_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.happens_during_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.intersects_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.is_congruent_to_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.is_tangent_to_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.overlaps_all_of_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.overlaps_only_start_of_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.overlaps_only_stop_of_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.overlaps_start_of_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.overlaps_stop_of_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.reflect
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.round_offsets
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.scale
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.set_duration
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.set_offsets
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.split_at_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.starts_after_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.starts_after_timespan_starts
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.starts_after_timespan_stops
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.starts_at_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.starts_at_or_after_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.starts_before_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.starts_before_or_at_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.starts_before_timespan_starts
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.starts_before_timespan_stops
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.starts_during_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.starts_when_timespan_starts
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.starts_when_timespan_stops
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.stops_after_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.stops_after_timespan_starts
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.stops_after_timespan_stops
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.stops_at_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.stops_at_or_after_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.stops_before_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.stops_before_or_at_offset
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.stops_before_timespan_starts
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.stops_before_timespan_stops
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.stops_during_timespan
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.stops_when_timespan_starts
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.stops_when_timespan_stops
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.stretch
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.translate
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.translate_offsets
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.trisects_timespan
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.__and__
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.__eq__
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.__format__
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.__ge__
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.__gt__
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.__le__
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.__len__
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.__lt__
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.__makenew__
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.__ne__
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.__or__
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.__repr__
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.__sub__
   :noindex:

.. automethod:: abjad.tools.timespantools.Timespan.Timespan.__xor__
   :noindex:
